@@ -24,7 +24,6 @@ Command-line interface to the OpenStack Magnum API.
 
 from __future__ import print_function
 import argparse
-import getpass
 import logging
 import os
 import sys
@@ -80,126 +79,6 @@ def positive_non_zero_float(text):
     return value
 
 
-class SecretsHelper(object):
-    def __init__(self, args, client):
-        self.args = args
-        self.client = client
-        self.key = None
-
-    def _validate_string(self, text):
-        if text is None or len(text) == 0:
-            return False
-        return True
-
-    def _make_key(self):
-        if self.key is not None:
-            return self.key
-        keys = [
-            self.client.auth_url,
-            self.client.projectid,
-            self.client.user,
-            self.client.region_name,
-            self.client.endpoint_type,
-            self.client.service_type,
-            self.client.service_name,
-            self.client.volume_service_name,
-        ]
-        for (index, key) in enumerate(keys):
-            if key is None:
-                keys[index] = '?'
-            else:
-                keys[index] = str(keys[index])
-        self.key = "/".join(keys)
-        return self.key
-
-    def _prompt_password(self, verify=True):
-        pw = None
-        if hasattr(sys.stdin, 'isatty') and sys.stdin.isatty():
-            # Check for Ctl-D
-            try:
-                while True:
-                    pw1 = getpass.getpass('OS Password: ')
-                    if verify:
-                        pw2 = getpass.getpass('Please verify: ')
-                    else:
-                        pw2 = pw1
-                    if pw1 == pw2 and self._validate_string(pw1):
-                        pw = pw1
-                        break
-            except EOFError:
-                pass
-        return pw
-
-    def save(self, auth_token, management_url, tenant_id):
-        if not HAS_KEYRING or not self.args.os_cache:
-            return
-        if (auth_token == self.auth_token and
-           management_url == self.management_url):
-            # Nothing changed....
-            return
-        if not all([management_url, auth_token, tenant_id]):
-            raise ValueError("Unable to save empty management url/auth token")
-        value = "|".join([str(auth_token),
-                          str(management_url),
-                          str(tenant_id)])
-        keyring.set_password("magnumclient_auth", self._make_key(), value)
-
-    @property
-    def password(self):
-        if self._validate_string(self.args.os_password):
-            return self.args.os_password
-        verify_pass = (
-            strutils.bool_from_string(cliutils.env("OS_VERIFY_PASSWORD"))
-        )
-        return self._prompt_password(verify_pass)
-
-    @property
-    def management_url(self):
-        if not HAS_KEYRING or not self.args.os_cache:
-            return None
-        management_url = None
-        try:
-            block = keyring.get_password('magnumclient_auth',
-                                         self._make_key())
-            if block:
-                _token, management_url, _tenant_id = block.split('|', 2)
-        except all_errors:
-            pass
-        return management_url
-
-    @property
-    def auth_token(self):
-        # Now is where it gets complicated since we
-        # want to look into the keyring module, if it
-        # exists and see if anything was provided in that
-        # file that we can use.
-        if not HAS_KEYRING or not self.args.os_cache:
-            return None
-        token = None
-        try:
-            block = keyring.get_password('magnumclient_auth',
-                                         self._make_key())
-            if block:
-                token, _management_url, _tenant_id = block.split('|', 2)
-        except all_errors:
-            pass
-        return token
-
-    @property
-    def tenant_id(self):
-        if not HAS_KEYRING or not self.args.os_cache:
-            return None
-        tenant_id = None
-        try:
-            block = keyring.get_password('magnumclient_auth',
-                                         self._make_key())
-            if block:
-                _token, _management_url, tenant_id = block.split('|', 2)
-        except all_errors:
-            pass
-        return tenant_id
-
-
 class MagnumClientArgumentParser(argparse.ArgumentParser):
 
     def __init__(self, *args, **kwargs):
@@ -432,8 +311,9 @@ class OpenStackMagnumShell(object):
                                 'data for performance profiling of operation. '
                                 'This key should be the value of the HMAC key '
                                 'configured for the OSprofiler middleware in '
-                                'nova; it is specified in the Nova '
-                                'configuration file at "/etc/nova/nova.conf". '
+                                'magnum; it is specified in the Magnum '
+                                'configuration file at '
+                                '"/etc/magnum/magnum.conf". '
                                 'Without the key, profiling will not be '
                                 'triggered even if OSprofiler is enabled on '
                                 'the server side.')
@@ -541,6 +421,36 @@ class OpenStackMagnumShell(object):
             api_major_version = versions[0]
             return (api_major_version, magnum_api_version)
 
+    def _ensure_auth_info(self, args):
+        if not cliutils.isunauthenticated(args.func):
+            if (not (args.os_token and
+                     (args.os_auth_url or args.os_endpoint_override)) and
+                not args.os_cloud
+                ):
+
+                if not (args.os_username or args.os_user_id):
+                    raise exc.CommandError(
+                        "You must provide a username via either --os-username "
+                        "or via env[OS_USERNAME]"
+                    )
+                if not args.os_password:
+                    raise exc.CommandError(
+                        "You must provide a password via either "
+                        "--os-password, env[OS_PASSWORD], or prompted "
+                        "response"
+                    )
+                if (not args.os_project_name and not args.os_project_id):
+                    raise exc.CommandError(
+                        "You must provide a project name or project id via "
+                        "--os-project-name, --os-project-id, "
+                        "env[OS_PROJECT_NAME] or env[OS_PROJECT_ID]"
+                    )
+                if not args.os_auth_url:
+                    raise exc.CommandError(
+                        "You must provide an auth url via either "
+                        "--os-auth-url or via env[OS_AUTH_URL]"
+                    )
+
     def main(self, argv):
 
         # NOTE(Christoph Jansen): With Python 3.4 argv somehow becomes a Map.
@@ -593,34 +503,8 @@ class OpenStackMagnumShell(object):
         args.os_project_id = (args.os_project_id or args.os_tenant_id)
         args.os_project_name = (args.os_project_name or args.os_tenant_name)
 
-        if not cliutils.isunauthenticated(args.func):
-            if (not (args.os_token and
-                     (args.os_auth_url or args.os_endpoint_override)) and
-                not args.os_cloud
-                ):
+        self._ensure_auth_info(args)
 
-                if not (args.os_username or args.os_user_id):
-                    raise exc.CommandError(
-                        "You must provide a username via either --os-username "
-                        "or via env[OS_USERNAME]"
-                    )
-                if not args.os_password:
-                    raise exc.CommandError(
-                        "You must provide a password via either "
-                        "--os-password, env[OS_PASSWORD], or prompted "
-                        "response"
-                    )
-                if (not args.os_project_name and not args.os_project_id):
-                    raise exc.CommandError(
-                        "You must provide a project name or project id via "
-                        "--os-project-name, --os-project-id, "
-                        "env[OS_PROJECT_NAME] or env[OS_PROJECT_ID]"
-                    )
-                if not args.os_auth_url:
-                    raise exc.CommandError(
-                        "You must provide an auth url via either "
-                        "--os-auth-url or via env[OS_AUTH_URL]"
-                    )
         try:
             client = {
                 '1': client_v1,
@@ -662,7 +546,11 @@ class OpenStackMagnumShell(object):
         )
 
         self._check_deprecation(args.func, argv)
-        args.func(self.cs, args)
+        try:
+            args.func(self.cs, args)
+        except (cliutils.DuplicateArgs, cliutils.MissingArgs):
+            self.do_help(args)
+            raise
 
         if profiler and args.profile:
             trace_id = profiler.get().get_base_id()
